AutoJson mixin

Mixin to provide automatic JSON parsing helpers

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

parseJson<T>(Map<String, dynamic> json, T constructor(Map<String, dynamic>)) → T
Helper method to automatically parse JSON to a type
parseJsonString<T>(String jsonString, T constructor(Map<String, dynamic>)) → T
Helper method to parse JSON string to object