DevLogger class

Constructors

DevLogger()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

logError(dynamic error, StackTrace? stackTrace, {String? context}) → void
logPortChange(int originalPort, int newPort) → void
logRequest({required String method, required String path, required int statusCode, required int responseTimeMs, String? clientIp}) → void
logServerError(dynamic error, String host, int port) → void
logShutdown() → void
printEndpoints(List<RouteInfo> routes) → void
printStartupBanner({required String host, required int port, bool isDevelopment = true, bool showDocs = true}) → void