DevelopmentConfig class

Constructors

DevelopmentConfig({bool enabled = true, bool showBanner = true, bool logRequests = true, bool logErrors = true, bool includeStackTrace = true, bool showEndpoints = true, bool enableDocs = true})
const

Properties

enabled bool
final
enableDocs bool
final
hashCode int
The hash code for this object.
no setterinherited
includeStackTrace bool
final
logErrors bool
final
logRequests bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showBanner bool
final
showEndpoints bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited