DocsConfig class

Constructors

DocsConfig({bool enabled = true, String title = 'glider_api', String version = '1.0.0', String description = 'Automatically generated API documentation', String docsPath = '/docs', String specPath = '/docs/openapi.json', String redocPath = '/redoc'})
const

Properties

description String
final
docsPath String
final
enabled bool
final
hashCode int
The hash code for this object.
no setterinherited
redocPath String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
specPath String
final
title String
final
version String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited