DocsGenerator class

Constructors

DocsGenerator({String title = 'mk_backend', String version = '1.0.0', String description = 'API documentation', String host = 'localhost', int port = 8080, List<String> schemes = const ['http'], dynamic apiClient})

Properties

apiClient → dynamic
final
description String
final
hashCode int
The hash code for this object.
no setterinherited
host String
final
port int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
schemes List<String>
final
title String
final
version String
final

Methods

generateOpenApiSpec(List<RouteInfo> routes) Map<String, dynamic>
generateReDocUI(String specUrl) String
generateSwaggerUI(String specUrl) String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerModel<T extends GliderModel>(String name, T constructor()) → void
Register a model for schema generation
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited