GliderModel class abstract

Base model class with validation support

Constructors

GliderModel()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Convert to JSON representation
toString() String
A string representation of this object.
inherited
validate(Map<String, dynamic> data) → void
Override this method to define validation rules
validateField<T>(String field, dynamic value, Validator<T> validator) → T
Helper method to validate a field

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson<T extends GliderModel>(Map<String, dynamic> data, T constructor()) → T
Validate and parse data into this model