GliderResponse class
Constructors
- GliderResponse([int _statusCode = 200])
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
body(
dynamic body) → GliderResponse -
header(
String name, String value) → GliderResponse -
headers(
Map< String, String> headers) → GliderResponse -
html(
String html) → GliderResponse -
json(
dynamic data) → GliderResponse -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
status(
int code) → GliderResponse -
text(
String text) → GliderResponse -
toShelfResponse(
) → Response -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
badRequest(
[dynamic body]) → GliderResponse -
created(
[dynamic body]) → GliderResponse -
forbidden(
[dynamic body]) → GliderResponse -
internalServerError(
[dynamic body]) → GliderResponse -
noContent(
) → GliderResponse -
notFound(
[dynamic body]) → GliderResponse -
ok(
[dynamic body]) → GliderResponse