IntValidator class

Integer validator with range constraints

Implemented types

Constructors

IntValidator({int? min, int? max, bool required = true})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
max int?
final
min int?
final
required bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
validate(String field, dynamic value) int
override

Operators

operator ==(Object other) bool
The equality operator.
inherited