JsonSerializable class abstract

Base class for automatic JSON serialization/deserialization

Constructors

JsonSerializable()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Convert this object to a JSON map
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson<T extends JsonSerializable>(Map<String, dynamic> json) → T
Create an instance from a JSON map This should be implemented by subclasses