ListValidator<T> class

List validator for arrays

Implemented types

Constructors

ListValidator(Validator<T> itemValidator, {int? minLength, int? maxLength, bool required = true})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
itemValidator Validator<T>
final
maxLength int?
final
minLength int?
final
required bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
validate(String field, dynamic value) List<T>
override

Operators

operator ==(Object other) bool
The equality operator.
inherited