RouteInfo class

Constructors

RouteInfo({required String path, required HttpMethod method, required dynamic handler, List<Middleware> middlewares = const [], dynamic dataConstructor, bool isTypedRoute = false})

Properties

dataConstructor → dynamic
final
handler → dynamic
final
hashCode int
The hash code for this object.
no setterinherited
isTypedRoute bool
final
method HttpMethod
final
middlewares List<Middleware>
final
path String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited