StringValidator class

String validator with various constraints

Implemented types
Implementers

Constructors

StringValidator({int? minLength, int? maxLength, RegExp? pattern, List<String>? allowedValues, bool required = true})
const

Properties

allowedValues List<String>?
final
hashCode int
The hash code for this object.
no setterinherited
maxLength int?
final
minLength int?
final
pattern RegExp?
final
required bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
validate(String field, dynamic value) String
override

Operators

operator ==(Object other) bool
The equality operator.
inherited