UrlValidator class

URL validator

Inheritance

Constructors

UrlValidator({bool required = true})

Properties

allowedValues List<String>?
finalinherited
hashCode int
The hash code for this object.
no setterinherited
maxLength int?
finalinherited
minLength int?
finalinherited
pattern RegExp?
finalinherited
required bool
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
validate(String field, dynamic value) String
override

Operators

operator ==(Object other) bool
The equality operator.
inherited