Validators class

Common validators for convenience

Constructors

Validators()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

email EmailValidator
final
url UrlValidator
final

Static Methods

integer({int? min, int? max, bool required = true}) IntValidator
list<T>(Validator<T> itemValidator, {int? minLength, int? maxLength, bool required = true}) ListValidator<T>
number({double? min, double? max, bool required = true}) DoubleValidator
string({int? minLength, int? maxLength, RegExp? pattern, List<String>? allowedValues, bool required = true}) StringValidator