GliderRequest class
Constructors
- GliderRequest(Request _request)
Properties
- clientIp → String?
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
headers
→ Map<
String, String> -
no setter
- isForm → bool
-
no setter
- isJson → bool
-
no setter
- method → String
-
no setter
-
pathParams
→ Map<
String, String> -
no setter
-
queryParams
→ Map<
String, String> -
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shelfRequest → Request
-
no setter
- url → Uri
-
no setter
- userAgent → String?
-
no setter
Methods
-
body(
) → Future< String> -
formData(
) → Future< Map< String, String> > -
header(
String name) → String? -
json(
) → Future< Map< String, dynamic> > -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
param(
String name) → String? -
query(
String name) → String? -
setPathParams(
Map< String, String> params) → void -
toString(
) → String -
A string representation of this object.
inherited
-
validate<
T extends GliderModel> (T constructor()) → Future< T> - Validate and parse JSON body into a model
-
validateField<
T> (String field, Validator< T> validator) → Future<T> - Validate specific field with a validator
-
validateParam<
T> (String name, Validator< T> validator) → T - Validate path parameter
-
validateQuery<
T> (String name, Validator< T> validator) → T - Validate query parameter
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited